@@ -1,7 +1,7 @@
 package Template::Mustache;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Drawing Mustaches on Perl for fun and profit
-$Template::Mustache::VERSION = '1.3.1';
+$Template::Mustache::VERSION = '1.3.2';
 use 5.12.0;
 
 use Moo;
@@ -29,7 +29,7 @@ has_ro template_path => (
         return unless defined $_[0];
         my $path = path($_[0]);
         die "'$_[0]' does not exist" unless $path->exists;
-        $path = $path->child('Mustache.mustache') 
+        $path = $path->child('Mustache.mustache')
             if $path->is_dir ;
         $path;
     },
@@ -37,7 +37,7 @@ has_ro template_path => (
 
 has_ro partials_path => (
     lazy => 1,
-    default => sub { 
+    default => sub {
         return unless $_[0]->template_path;
         $_[0]->template_path->parent;
     },
@@ -65,26 +65,29 @@ has_rw template => (
 
 has_rw parsed => (
     clearer => 1,
-    lazy => 1, 
+    lazy => 1,
     default => sub {
         my $self = shift;
-        $self->parser->template( 
-            $self->template, 
-            undef, 
-            @{ $self->delimiters } 
+        $self->parser->template(
+            $self->template,
+            undef,
+            @{ $self->delimiters }
         );
     },
 );
 
 has_rw delimiters => (
-    lazy => 1, 
+    lazy => 1,
     default => sub { [ '{{', '}}' ] },
 );
 
+use Scalar::Util qw/ weaken /;
+
 has_rw partials => (
     lazy => 1,
-    default => sub { 
+    default => sub {
         my $self = shift;
+        weaken $self;
 
         return sub {
             state $partials = {};
@@ -120,8 +123,8 @@ sub _parse_partials {
 
     while( my ( $name, $template ) = each %$partials ) {
         next if ref $template;
-        $partials->{$name} = 
-            Template::Mustache->new( template => 
+        $partials->{$name} =
+            Template::Mustache->new( template =>
                 ref $template ? $template->($name) : $template )->parsed;
     }
 
@@ -130,15 +133,15 @@ sub _parse_partials {
 
 has_ro parser => sub {
     if ( $ENV{MUSTACHE_DEBUG} ) {
-        return Parse::RecDescent->new( 
+        return Parse::RecDescent->new(
             $Template::Mustache::GRAMMAR
         );
     }
 
-    return Template::Mustache::Parser->new 
+    return Template::Mustache::Parser->new
 };
 
-sub render {  
+sub render {
     my $self = shift;
 
     unless( ref $self ) {
@@ -154,7 +157,7 @@ sub render {
 }
 
 
-sub resolve_context {  
+sub resolve_context {
     my ( $key, $context ) = @_;
 
     no warnings 'uninitialized';
@@ -185,7 +188,7 @@ sub resolve_context {
 
 our $GRAMMAR = <<'END_GRAMMAR';
 
-<skip:qr//> 
+<skip:qr//>
 
 eofile: /^\Z/
 
@@ -294,15 +297,15 @@ standalone_surround: /\s*/ opening_tag /\s*/ <matchrule:$arg[0]_inner> closing_t
     [  @item[1,6,4] ],
 }
 
-comment: standalone_surround[$item[0]] { 
-    Template::Mustache::Token::Verbatim->new( 
+comment: standalone_surround[$item[0]] {
+    Template::Mustache::Token::Verbatim->new(
         content => $item[1][0] . $item[1][1]
     ),
 }
 
 comment_inner: '!' { $thisparser->{closing_tag} } /.*?(?=\Q$item[2]\E)/s
 
-inner_section: ...!close_section[ $arg[0] ] template_item 
+inner_section: ...!close_section[ $arg[0] ] template_item
 
 section: open_section {$thisoffset} inner_section[ $item[1][0] ](s?) {$thisoffset
     - $item[2]
@@ -315,9 +318,9 @@ section: open_section {$thisoffset} inner_section[ $item[1][0] ](s?) {$thisoffse
             variable => $item[1][0],
             inverse => $item[1][1],
             raw => $raw,
-            template => Template::Mustache::Token::Template->new( 
-                items => [ 
-                    $item[1][3], @{$item[3]}, $item[5][0] ], 
+            template => Template::Mustache::Token::Template->new(
+                items => [
+                    $item[1][3], @{$item[3]}, $item[5][0] ],
             )
         ),
         $item[5][1]
@@ -329,7 +332,7 @@ unescaped_variable: /\s*/ opening_tag '{' /\s*/ variable_name /\s*/ '}' closing_
     Template::Mustache::Token::Template->new(
         items => [
             Template::Mustache::Token::Verbatim->new( content => $item[1] ),
-            Template::Mustache::Token::Variable->new( 
+            Template::Mustache::Token::Variable->new(
                 name => $item{variable_name},
                 escape => 0,
             ),
@@ -341,7 +344,7 @@ unescaped_variable_amp: /\s*/ opening_tag '&' /\s*/ variable_name /\s*/ closing_
     Template::Mustache::Token::Template->new(
         items => [
             Template::Mustache::Token::Verbatim->new( content => $item[1] ),
-            Template::Mustache::Token::Variable->new( 
+            Template::Mustache::Token::Variable->new(
                 name => $item{variable_name},
                 escape => 0,
             ),
@@ -382,7 +385,7 @@ Template::Mustache - Drawing Mustaches on Perl for fun and profit
 
 =head1 VERSION
 
-version 1.3.1
+version 1.3.2
 
 =head1 SYNOPSIS
 
@@ -703,7 +706,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2011 by Pieter van de Bruggen.
+This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2011 by Pieter van de Bruggen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -882,7 +885,6 @@ sub generate {
             my ($ctx, $value) = lookup($tag, @context) unless $type eq '>';
 
             if ($type eq '{' || $type eq '&' || $type eq '') {
-                $DB::single = 1;
                 # Interpolation Tags
                 # If the value is a code reference, we should treat it
                 # according to Mustache's lambda rules.  Specifically, we
@@ -909,8 +911,7 @@ sub generate {
                 #    and a rendering function are passed to the sub; the return
                 #    value is then automatically rendered.
                 #  * Otherwise, the section is rendered using given value.
-                $DB::single = 1;
-                
+
                 if (ref $value eq 'ARRAY') {
                     @result = map { $build->(@$data, $_) } @$value;
                 } elsif ($value) {
